==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_02_libftdi.sh <==
#!/bin/bash

#
#  Install script for USB serial port chip driver as required to compile OpenOCD
#  Script written by Gregor Rebel 2010-2011.
#  libFTDI - FTDI USB driver with bitbang mode
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh


if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="999_libftdi"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------


  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" == "" ]; then #{ install missing packages
    installPackageSafe "which libusb-config" libusb-dev
  fi #}
  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" != "" ]; then #{ check if installation was successfull
    touch OK.Packages
  else
    echo "$0 - ERROR: Cannot install libusb which is required to compile libftdi!"
    exit 10
  fi #}
  
  LibUSB_Version=`libusb-config --version`
  LibUSB_Major=`perl -e "print substr('$LibUSB_Version',0,1);"`
  if [ "$LibUSB_Major" == "0" ]; then
    findNewest http://www.libusb.org/ "libusb-1.*bz2"
  fi

if [ ! -e OK.Install ]; then #{

  echo "installing in $INSTALLPATH ..."
  
  #Version="0.18"
  #Version="0.19"
  Version="0.20"
  
  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" == "" ]; then #{
    installPackage "libusb-devel"
    installPackage "libusb-dev"
    installPackage "libusb-1_0-devel"
    installPackage "libusb*-dev*"
    installPackage "libusb-compat-devel"
    installPackage "libusb"
    installPackage "libusb-dev"

    # on sime distros (e.g. Xubuntu 11.10, libusb does not get installed correctly at first run)
    installPackage "libusb-devel"
    installPackage "libusb-dev"
    installPackage "libusb-1_0-devel"
    installPackage "libusb*-dev*"
    installPackage "libusb-compat-devel"
    installPackage "libusb"
    installPackage "libusb-dev"
    
    #X updatedb

  fi #}
  
  Error=""
  if [ ! -e OK.Install_libftdi ]; then #{
    Folder="libftdi-${Version}"
    getFile http://www.intra2net.com/de/produkte/opensource/ftdi/TGZ/ $Folder.tar.gz
    untgz $Folder $Folder.tar.gz
    add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$Folder"
    
    InstallInHomeDir="0"
    if [ "$InstallInHomeDir" == "1" ]; then
      Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
    else
      findPrefix   # install for all users
    fi
    cd "$Folder"
    Error="libftdi"
    ./configure --prefix=$Prefix   >configure.log 2>configure.err && \
                make -j2           >make.log      2>make.err && \
                sudo make install  >install.log   2>install.err && \
                Error=""
    cd ..
    if [ "$Error" == "" ]; then
      cp -R $Folder/doc ../../Documentation/libftdi
      touch OK.Install_libftdi
    fi
    fi #}Install_libftdi
  if [ ! -e OK.Install_ft232r_prog ]; then #{
    #Version="1.07"
    Version="1.10"
    Folder="ft232r_prog-${Version}"
    getFile http://rtr.ca/ft232r/ ${Folder}.tar.gz
    untgz "v" ${Folder}.tar.gz
    cd "ft232r_prog-${Version}"
    replaceInFile Makefile "-Werror" ""
    make
    if [ -e ft232r_prog ]; then
      touch ../OK.Install_ft232r_prog
      createLink ../$INSTALLPATH/$Folder/ft232r_prog ../../bin/ft232r_prog
    fi
      
    cd ..
    dir ../../Documentation/bin
    get http://rtr.ca/ft232r/ index.html ../../Documentation/bin/ft232r.html

  fi #}Install_ft232r_prog

  
  if [ "$Error" == "" ]; then #{
    if [ "$InstallInHomeDir" != "1" ]; then
      sudo /sbin/ldconfig
    fi

    echo "" >OK.Install
  else
    echo "Error occured during compilation ($Error)!"
    echo "check logfiles:"
    find `pwd`/ -name "*.log" -exec echo "  less {}" \;
    find `pwd`/ -name "*.err" -exec echo "  less {}" \;
  fi #}

fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  if [ "$InstallInHomeDir" == "1" ]; then

    addLine ../scripts/SourceMe.sh "export LD_LIBRARY_PATH=\"$Prefix/lib:\$LD_LIBRARY_PATH\" #$0"
    addLine ../scripts/SourceMe.sh "export PATH=\"$Prefix/bin:\$PATH\" #$0"
  fi
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/ToolChain/install_02_libftdi.sh <==
#!/bin/bash

#
#  Install script for USB serial port chip driver as required to compile OpenOCD
#  Script written by Gregor Rebel 2010-2011.
#  libFTDI - FTDI USB driver with bitbang mode
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh
checkUserRoot "$1" "$2"

StartPath="`pwd`"
INSTALLPATH="999_libftdi"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------


  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" == "" ]; then #{ install missing packages
    installPackageSafe "which libusb-config" libusb-dev
  fi #}
  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" != "" ]; then #{ check if installation was successfull
    touch OK.Packages
  else
    echo "$0 - ERROR: Cannot install libusb which is required to compile libftdi!"
    exit 10
  fi #}
  
  LibUSB_Version=`libusb-config --version`
  LibUSB_Major=`perl -e "print substr('$LibUSB_Version',0,1);"`
  #? if [ "$LibUSB_Major" == "0" ]; then
    #? echo "looking for newest libusb from http://www.libusb.org/..."
    #? findNewest http://www.libusb.org/ "libusb-1.*bz2"
  #? fi

if [ ! -e OK.Install ]; then #{

  echo "installing in $INSTALLPATH ..."
  
  #Version="0.18"
  #Version="0.19"
  Version="0.20"
  
  LibUSB_Found=`which libusb-config`
  if [ "$LibUSB_Found" == "" ]; then #{
    echo "installing missing packages..."
    installPackage "libusb-devel"
    installPackage "libusb-dev"
    installPackage "libusb-1_0-devel"
    installPackage "libusb*-dev*"
    installPackage "libusb-compat-devel"
    installPackage "libusb"
    installPackage "libusb-dev"

    # on sime distros (e.g. Xubuntu 11.10, libusb does not get installed correctly at first run)
    installPackage "libusb-devel"
    installPackage "libusb-dev"
    installPackage "libusb-1_0-devel"
    installPackage "libusb*-dev*"
    installPackage "libusb-compat-devel"
    installPackage "libusb"
    installPackage "libusb-dev"
    
    #X updatedb

  fi #}
  
  Error=""
  if [ ! -e OK.Install_libftdi ]; then #{
    echo "installing libftdi..."
    Folder="libftdi-${Version}"
    getFile http://www.intra2net.com/de/produkte/opensource/ftdi/TGZ/ $Folder.tar.gz
    untgz $Folder $Folder.tar.gz
    add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$Folder"
    
    InstallInHomeDir="0"
    if [ "$InstallInHomeDir" == "1" ]; then
      Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
    else
      findPrefix   # install for all users
    fi
    cd "$Folder"
    Error="libftdi"
    ./configure --prefix=$Prefix   >configure.log 2>configure.err && \
                make -j2           >make.log      2>make.err && \
                sudo make install  >install.log   2>install.err && \
                Error=""
    cd ..
    if [ "$Error" == "" ]; then
      cp -R $Folder/doc ../../Documentation/libftdi
      touch OK.Install_libftdi
    fi
    fi #}Install_libftdi
  if [ ! -e OK.Install_ft232r_prog ]; then #{
    echo "installing ft232r_prog..."
    #Version="1.07"
    Version="1.10"
    Folder="ft232r_prog-${Version}"
    getFile http://rtr.ca/ft232r/ ${Folder}.tar.gz
    untgz "v" ${Folder}.tar.gz
    cd "ft232r_prog-${Version}"
    replaceInFile Makefile "-Werror" ""
    make
    if [ -e ft232r_prog ]; then
      touch ../OK.Install_ft232r_prog
      createLink ../$INSTALLPATH/$Folder/ft232r_prog ../../bin/ft232r_prog
    fi
      
    cd ..
    dir ../../Documentation/bin
    get http://rtr.ca/ft232r/ index.html ../../Documentation/bin/ft232r.html

  fi #}Install_ft232r_prog

  
  if [ "$Error" == "" ]; then #{
    if [ "$InstallInHomeDir" != "1" ]; then
      sudo /sbin/ldconfig
    fi

    echo "" >OK.Install
  else
    echo "Error occured during compilation ($Error)!"
    echo "check logfiles:"
    find `pwd`/ -name "*.log" -exec echo "  less {}" \;
    find `pwd`/ -name "*.err" -exec echo "  less {}" \;
  fi #}

fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  if [ "$InstallInHomeDir" == "1" ]; then

    addLine ../scripts/SourceMe.sh "export LD_LIBRARY_PATH=\"$Prefix/lib:\$LD_LIBRARY_PATH\" #$0"
    addLine ../scripts/SourceMe.sh "export PATH=\"$Prefix/bin:\$PATH\" #$0"
  fi
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

cd "$StartPath"
applyTargetUserAndGroup "$INSTALLPATH"

exit 0
